# dataprovider-py

## Installation
This package is available on PyPI as datalab:

pip install datalab
## Using in Jupyter
After datalab installation, enable datalab's frontend in Jupyter by running:

jupyter nbextension install --py datalab.notebook --sys-prefix
See further details Jupyter Kernel and Notebook Extensions.